"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkspaceContribution = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ide_overlay_1 = require("@opensumi/ide-overlay");
const common_1 = require("../common");
const workspace_contextkey_1 = require("./workspace-contextkey");
const workspace_preferences_1 = require("./workspace-preferences");
const workspace_service_1 = require("./workspace-service");
let WorkspaceContribution = class WorkspaceContribution {
    constructor() {
        this.schema = workspace_preferences_1.workspacePreferenceSchema;
    }
    async initWorkspaceContextKeys() {
        await this.workspaceService.whenReady;
        const updateWorkspaceFolderCountKey = () => {
            const roots = this.workspaceService.tryGetRoots();
            this.workspaceContextKey.workbenchStateContextKey.set(roots.length > 1 ? 'workspace' : 'folder');
            this.workspaceContextKey.workspaceFolderCountContextKey.set(roots.length);
        };
        updateWorkspaceFolderCountKey();
        this.workspaceService.onWorkspaceLocationChanged(updateWorkspaceFolderCountKey);
    }
    async onStart() {
        this.initWorkspaceContextKeys();
    }
    registerCommands(registry) {
        registry.registerCommand(ide_core_browser_1.WORKSPACE_COMMANDS.ADD_WORKSPACE_FOLDER, {
            execute: async () => {
                const folder = await this.windowDialogService.showOpenDialog({
                    canSelectFiles: false,
                    canSelectFolders: true,
                    canSelectMany: false,
                });
                if (folder && folder.length > 0) {
                    await this.workspaceService.addRoot(folder[0]);
                }
            },
        });
        registry.registerCommand(ide_core_browser_1.WORKSPACE_COMMANDS.SAVE_WORKSPACE_AS_FILE, {
            execute: async () => {
                if (!this.workspaceService.isMultiRootWorkspaceOpened) {
                    // 非工作区模式下调用无效
                    return;
                }
                const folder = await this.windowDialogService.showSaveDialog({
                    saveLabel: (0, ide_core_browser_1.localize)('workspace.saveWorkspaceAsFile'),
                    showNameInput: true,
                    defaultFileName: `workspace.${common_1.DEFAULT_WORKSPACE_SUFFIX_NAME}`,
                });
                if (folder) {
                    await this.workspaceService.save(folder);
                }
            },
        });
        registry.registerCommand(ide_core_browser_1.WORKSPACE_COMMANDS.REMOVE_WORKSPACE_FOLDER, {
            execute: async (_, uris) => {
                if (!uris.length || !this.workspaceService.isMultiRootWorkspaceOpened) {
                    return;
                }
                const roots = await this.workspaceService.roots;
                const workspaceUris = uris.filter((uri) => roots.find((file) => file.uri === uri.toString()));
                if (workspaceUris.length > 0) {
                    await this.workspaceService.removeRoots(workspaceUris);
                }
            },
        });
    }
    onFileServiceReady() {
        this.workspaceService.init();
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IWorkspaceService),
    tslib_1.__metadata("design:type", workspace_service_1.WorkspaceService)
], WorkspaceContribution.prototype, "workspaceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.CommandRegistry),
    tslib_1.__metadata("design:type", Object)
], WorkspaceContribution.prototype, "commandRegistry", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(workspace_contextkey_1.WorkspaceContextKey),
    tslib_1.__metadata("design:type", workspace_contextkey_1.WorkspaceContextKey)
], WorkspaceContribution.prototype, "workspaceContextKey", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_overlay_1.IWindowDialogService),
    tslib_1.__metadata("design:type", Object)
], WorkspaceContribution.prototype, "windowDialogService", void 0);
WorkspaceContribution = tslib_1.__decorate([
    (0, ide_core_browser_1.Domain)(ide_core_browser_1.ClientAppContribution, ide_core_browser_1.PreferenceContribution, ide_core_browser_1.FsProviderContribution, ide_core_browser_1.CommandContribution)
], WorkspaceContribution);
exports.WorkspaceContribution = WorkspaceContribution;
//# sourceMappingURL=workspace-contribution.js.map