import { FileStat } from '@opensumi/ide-file-service';
export interface WorkspaceData {
    folders: Array<{
        path: string;
        name?: string;
    }>;
    settings?: {
        [id: string]: any;
    };
}
export declare namespace WorkspaceData {
    function is(data: any): data is WorkspaceData;
    function buildWorkspaceData(folders: string[] | FileStat[], settings: {
        [id: string]: any;
    } | undefined): WorkspaceData;
    /**
     * 存储时需要将 {workspace}.sumi-workspace 内容存储为相对路径存储
     * 1. 如果可用相对路径表示，则存储为:
     * {
     *  "folders": [
     *    {
     *       "path": "folder1"
     *     },
     *     {
     *       "path": "folder2"
     *     }
     *   ],
     * }
     *
     * 2. 如果不可用相对路径表示，则存储绝对路径：
     * {
     *  "folders": [
     *    {
     *       "path": "file://abc/folder1"
     *     },
     *     {
     *       "path": "file://cdf/folder2"
     *     }
     *   ],
     * }
     *
     * @export
     * @param {WorkspaceData} data
     * @param {FileStat} [workspaceFile]
     * @returns {WorkspaceData}
     */
    function transformToRelative(data: WorkspaceData, workspaceFile?: FileStat): WorkspaceData;
    /**
     * 将 {workspace}.sumi-workspace 中存储的相对路径转换为绝对路径
     *
     * @export
     * @param {WorkspaceData} data
     * @param {FileStat} [workspaceFile]
     * @returns {WorkspaceData}
     */
    function transformToAbsolute(data: WorkspaceData, workspaceFile?: FileStat): WorkspaceData;
}
//# sourceMappingURL=workspace-data.d.ts.map