"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkspaceVariableContribution = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const common_1 = require("../common");
let WorkspaceVariableContribution = class WorkspaceVariableContribution {
    registerVariables(variables) {
        variables.registerVariable({
            name: 'workspaceRoot',
            description: 'The path of the workspace root folder',
            resolve: (context) => {
                const uri = this.getWorkspaceRootUri(context);
                return uri && uri.path.toString();
            },
        });
        variables.registerVariable({
            name: 'workspaceFolder',
            description: 'The path of the workspace root folder',
            resolve: (context) => {
                const uri = this.getWorkspaceRootUri(context);
                return uri && uri.codeUri.fsPath.toString();
            },
        });
        variables.registerVariable({
            name: 'workspaceFolderBasename',
            description: 'The name of the workspace root folder',
            resolve: (context) => {
                const uri = this.getWorkspaceRootUri(context);
                return uri && uri.displayName;
            },
        });
        variables.registerVariable({
            name: 'cwd',
            description: 'The path of the current working directory',
            resolve: (context) => {
                const uri = this.getWorkspaceRootUri(context);
                return (uri && uri.codeUri.fsPath.toString()) || '';
            },
        });
        variables.registerVariable({
            name: 'file',
            description: 'The path of the currently opened file',
            resolve: async () => {
                const uri = await this.getResourceUri();
                return uri && uri.codeUri.fsPath.toString();
            },
        });
        variables.registerVariable({
            name: 'fileBasename',
            description: 'The basename of the currently opened file',
            resolve: async () => {
                const uri = await this.getResourceUri();
                return uri && uri.path.base;
            },
        });
        variables.registerVariable({
            name: 'fileBasenameNoExtension',
            description: "The currently opened file's name without extension",
            resolve: async () => {
                const uri = await this.getResourceUri();
                return uri && uri.path.name;
            },
        });
        variables.registerVariable({
            name: 'fileDirname',
            description: "The name of the currently opened file's directory",
            resolve: async () => {
                const uri = await this.getResourceUri();
                return uri && uri.path.dir.toString();
            },
        });
        variables.registerVariable({
            name: 'fileExtname',
            description: 'The extension of the currently opened file',
            resolve: async () => {
                const uri = await this.getResourceUri();
                return uri && uri.path.ext;
            },
        });
        variables.registerVariable({
            name: 'relativeFile',
            description: "The currently opened file's path relative to the workspace root",
            resolve: async () => {
                const uri = await this.getResourceUri();
                return uri && this.getWorkspaceRelativePath(uri);
            },
        });
        variables.registerVariable({
            name: 'env',
            resolve: async () => {
                const envVariable = await this.commandService.executeCommand(ide_core_browser_1.COMMON_COMMANDS.ENVIRONMENT_VARIABLE.id);
                return envVariable;
            },
        });
    }
    getWorkspaceRootUri(uri) {
        return this.workspaceService.getWorkspaceRootUri(uri);
    }
    async getResourceUri() {
        const currentResource = await this.commandService.executeCommand(ide_core_browser_1.EDITOR_COMMANDS.GET_CURRENT_RESOURCE.id);
        if (currentResource) {
            return currentResource.uri;
        }
        return undefined;
    }
    getWorkspaceRelativePath(uri) {
        const workspaceRootUri = this.getWorkspaceRootUri(uri);
        const path = workspaceRootUri && workspaceRootUri.path.relative(uri.path);
        return path && path.toString();
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IWorkspaceService),
    tslib_1.__metadata("design:type", Object)
], WorkspaceVariableContribution.prototype, "workspaceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.CommandService),
    tslib_1.__metadata("design:type", Object)
], WorkspaceVariableContribution.prototype, "commandService", void 0);
WorkspaceVariableContribution = tslib_1.__decorate([
    (0, ide_core_browser_1.Domain)(ide_core_browser_1.VariableContribution)
], WorkspaceVariableContribution);
exports.WorkspaceVariableContribution = WorkspaceVariableContribution;
//# sourceMappingURL=workspace-variable-contribution.js.map