"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockWorkspaceService = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_common_1 = require("@opensumi/ide-core-common");
let MockWorkspaceService = class MockWorkspaceService {
    constructor() {
        this._roots = [];
        this.isMultiRootWorkspaceOpened = false;
        this.deferredRoots = new ide_core_common_1.Deferred();
        this._onWorkspaceChanged = new ide_core_common_1.Emitter();
        this.onWorkspaceChanged = this._onWorkspaceChanged.event;
        this._onWorkspaceLocationChanged = new ide_core_common_1.Emitter();
        this.onWorkspaceLocationChanged = this._onWorkspaceLocationChanged.event;
        this._onWorkspaceFileExcludeChangeEmitter = new ide_core_common_1.Emitter();
        this.onWorkspaceFileExcludeChanged = this._onWorkspaceFileExcludeChangeEmitter.event;
        this.whenReady = this.init();
    }
    async init() {
        await this.setWorkspace();
    }
    async initFileServiceExclude() {
        // do nothing
    }
    async setWorkspace(workspaceStat) {
        await this.updateWorkspace(workspaceStat);
    }
    async updateWorkspace(workspaceStat) {
        await this.updateRoots(workspaceStat);
        this._onWorkspaceChanged.fire(this._roots);
    }
    containsSome(paths) {
        throw new Error('Method not implemented.');
    }
    get roots() {
        return this.deferredRoots.promise;
    }
    get workspace() {
        return this._workspace;
    }
    tryGetRoots() {
        return this._roots;
    }
    async updateRoots(workspaceStat) {
        const root = workspaceStat || {
            isDirectory: true,
            uri: 'file://userhome/',
            lastModification: 0,
        };
        this._workspace = root;
        this._roots = [root];
        this.deferredRoots = new ide_core_common_1.Deferred();
        this.deferredRoots.resolve(this._roots);
        this._onWorkspaceChanged.fire(this._roots);
    }
    async setMostRecentlyUsedWorkspace() {
        return;
    }
    getMostRecentlyUsedWorkspace() {
        throw new Error('Method not implemented.');
    }
    getMostRecentlyUsedWorkspaces() {
        throw new Error('Method not implemented.');
    }
    getMostRecentlyUsedCommands() {
        throw new Error('Method not implemented.');
    }
    setMostRecentlyUsedCommand(commandId) {
        throw new Error('Method not implemented.');
    }
    async setMostRecentlyOpenedFile(uri) {
        return;
    }
    getMostRecentlyOpenedFiles() {
        throw new Error('Method not implemented.');
    }
    setMostRecentlySearchWord(word) {
        throw new Error('Method not implemented.');
    }
    getMostRecentlySearchWord() {
        throw new Error('Method not implemented.');
    }
    async removeRoots(uri) {
        return;
    }
    async spliceRoots(start, deleteCount, workspaceName, ...rootsToAdd) {
        this._roots = rootsToAdd.map((root) => ({ isDirectory: true, uri: root.toString(), lastModification: 0 }));
        this.deferredRoots = new ide_core_common_1.Deferred();
        this.deferredRoots.resolve(this._roots);
        return rootsToAdd;
    }
    asRelativePath(pathOrUri, includeWorkspaceFolder) {
        throw new Error('Method not implemented.');
    }
    getWorkspaceRootUri(uri) {
        return new ide_core_common_1.URI(this._roots[0].uri);
    }
    getWorkspaceName(uri) {
        return '';
    }
};
MockWorkspaceService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], MockWorkspaceService);
exports.MockWorkspaceService = MockWorkspaceService;
//# sourceMappingURL=workspace-service.js.map